@@ -2,7 +2,7 @@ use {super::*, serde::Serialize};
 
 #[derive(Debug)]
 struct Invocation<'src: 'run, 'run> {
-  arguments: &'run [&'run str],
+  arguments: Vec<&'run str>,
   recipe: &'run Recipe<'src>,
   settings: &'run Settings<'src>,
   scope: &'run Scope<'src, 'run>,
@@ -23,10 +23,6 @@ pub(crate) struct Justfile<'src> {
 }
 
 impl<'src> Justfile<'src> {
-  pub(crate) fn count(&self) -> usize {
-    self.recipes.len()
-  }
-
   pub(crate) fn suggest_recipe(&self, input: &str) -> Option<Suggestion<'src>> {
     let mut suggestions = self
       .recipes
@@ -120,7 +116,7 @@ impl<'src> Justfile<'src> {
     search: &Search,
     overrides: &BTreeMap<String, String>,
     arguments: &[String],
-  ) -> RunResult<'src, ()> {
+  ) -> RunResult<'src> {
     let unknown_overrides = overrides
       .keys()
       .filter(|name| !self.assignments.contains_key(name.as_str()))
@@ -213,7 +209,7 @@ impl<'src> Justfile<'src> {
       _ => {}
     }
 
-    let argvec: Vec<&str> = if !arguments.is_empty() {
+    let mut remaining: Vec<&str> = if !arguments.is_empty() {
       arguments.iter().map(String::as_str).collect()
     } else if let Some(recipe) = &self.default {
       recipe.check_can_be_default_recipe()?;
@@ -224,15 +220,25 @@ impl<'src> Justfile<'src> {
       return Err(Error::NoDefaultRecipe);
     };
 
-    let arguments = argvec.as_slice();
-
     let mut missing = Vec::new();
     let mut invocations = Vec::new();
-    let mut remaining = arguments;
     let mut scopes = BTreeMap::new();
     let arena: Arena<Scope> = Arena::new();
 
-    while let Some((first, mut rest)) = remaining.split_first() {
+    while let Some(first) = remaining.first().copied() {
+      if first.contains("::")
+        && !(first.starts_with(':') || first.ends_with(':') || first.contains(":::"))
+      {
+        remaining = first
+          .split("::")
+          .chain(remaining[1..].iter().copied())
+          .collect();
+
+        continue;
+      }
+
+      let rest = &remaining[1..];
+
       if let Some((invocation, consumed)) = self.invocation(
         0,
         &mut Vec::new(),
@@ -245,12 +251,12 @@ impl<'src> Justfile<'src> {
         first,
         rest,
       )? {
-        rest = &rest[consumed..];
+        remaining = rest[consumed..].to_vec();
         invocations.push(invocation);
       } else {
-        missing.push((*first).to_owned());
+        missing.push(first.to_string());
+        remaining = rest.to_vec();
       }
-      remaining = rest;
     }
 
     if !missing.is_empty() {
@@ -265,7 +271,7 @@ impl<'src> Justfile<'src> {
       });
     }
 
-    let mut ran = BTreeSet::new();
+    let mut ran = Ran::default();
     for invocation in invocations {
       let context = RecipeContext {
         settings: invocation.settings,
@@ -275,12 +281,17 @@ impl<'src> Justfile<'src> {
       };
 
       Self::run_recipe(
+        &invocation
+          .arguments
+          .iter()
+          .copied()
+          .map(str::to_string)
+          .collect::<Vec<String>>(),
         &context,
-        invocation.recipe,
-        invocation.arguments,
         &dotenv,
-        search,
         &mut ran,
+        invocation.recipe,
+        search,
       )?;
     }
 
@@ -310,7 +321,7 @@ impl<'src> Justfile<'src> {
     search: &'run Search,
     parent: &'run Scope<'src, 'run>,
     first: &'run str,
-    rest: &'run [&'run str],
+    rest: &[&'run str],
   ) -> RunResult<'src, Option<(Invocation<'src, 'run>, usize)>> {
     if let Some(module) = self.modules.get(first) {
       path.push(first);
@@ -331,7 +342,7 @@ impl<'src> Justfile<'src> {
             Invocation {
               settings: &module.settings,
               recipe,
-              arguments: &[],
+              arguments: Vec::new(),
               scope,
             },
             depth,
@@ -356,7 +367,7 @@ impl<'src> Justfile<'src> {
       if recipe.parameters.is_empty() {
         Ok(Some((
           Invocation {
-            arguments: &[],
+            arguments: Vec::new(),
             recipe,
             scope: parent,
             settings: &self.settings,
@@ -377,7 +388,7 @@ impl<'src> Justfile<'src> {
         }
         Ok(Some((
           Invocation {
-            arguments: &rest[..argument_count],
+            arguments: rest[..argument_count].to_vec(),
             recipe,
             scope: parent,
             settings: &self.settings,
@@ -391,19 +402,14 @@ impl<'src> Justfile<'src> {
   }
 
   fn run_recipe(
+    arguments: &[String],
     context: &RecipeContext<'src, '_>,
-    recipe: &Recipe<'src>,
-    arguments: &[&str],
     dotenv: &BTreeMap<String, String>,
+    ran: &mut Ran<'src>,
+    recipe: &Recipe<'src>,
     search: &Search,
-    ran: &mut BTreeSet<Vec<String>>,
-  ) -> RunResult<'src, ()> {
-    let mut invocation = vec![recipe.name().to_owned()];
-    for argument in arguments {
-      invocation.push((*argument).to_string());
-    }
-
-    if ran.contains(&invocation) {
+  ) -> RunResult<'src> {
+    if ran.has_run(&recipe.namepath, arguments) {
       return Ok(());
     }
 
@@ -428,26 +434,21 @@ impl<'src> Justfile<'src> {
     let mut evaluator =
       Evaluator::recipe_evaluator(context.config, dotenv, &scope, context.settings, search);
 
-    for Dependency { recipe, arguments } in recipe.dependencies.iter().take(recipe.priors) {
-      let arguments = arguments
-        .iter()
-        .map(|argument| evaluator.evaluate_expression(argument))
-        .collect::<RunResult<Vec<String>>>()?;
+    if !context.config.no_dependencies {
+      for Dependency { recipe, arguments } in recipe.dependencies.iter().take(recipe.priors) {
+        let arguments = arguments
+          .iter()
+          .map(|argument| evaluator.evaluate_expression(argument))
+          .collect::<RunResult<Vec<String>>>()?;
 
-      Self::run_recipe(
-        context,
-        recipe,
-        &arguments.iter().map(String::as_ref).collect::<Vec<&str>>(),
-        dotenv,
-        search,
-        ran,
-      )?;
+        Self::run_recipe(&arguments, context, dotenv, ran, recipe, search)?;
+      }
     }
 
     recipe.run(context, dotenv, scope.child(), search, &positional)?;
 
-    {
-      let mut ran = BTreeSet::new();
+    if !context.config.no_dependencies {
+      let mut ran = Ran::default();
 
       for Dependency { recipe, arguments } in recipe.dependencies.iter().skip(recipe.priors) {
         let mut evaluated = Vec::new();
@@ -456,18 +457,11 @@ impl<'src> Justfile<'src> {
           evaluated.push(evaluator.evaluate_expression(argument)?);
         }
 
-        Self::run_recipe(
-          context,
-          recipe,
-          &evaluated.iter().map(String::as_ref).collect::<Vec<&str>>(),
-          dotenv,
-          search,
-          &mut ran,
-        )?;
+        Self::run_recipe(&evaluated, context, dotenv, &mut ran, recipe, search)?;
       }
     }
 
-    ran.insert(invocation);
+    ran.ran(&recipe.namepath, arguments.to_vec());
     Ok(())
   }
 
@@ -476,7 +470,7 @@ impl<'src> Justfile<'src> {
       .recipes
       .values()
       .map(AsRef::as_ref)
-      .filter(|recipe| recipe.public())
+      .filter(|recipe| recipe.is_public())
       .collect::<Vec<&Recipe<Dependency>>>();
 
     if source_order {
