@@ -59,7 +59,14 @@ pub(crate) fn analysis_error(
 ) {
   let tokens = Lexer::test_lex(src).expect("Lexing failed in parse test...");
 
-  let ast = Parser::parse(&tokens).expect("Parsing failed in analysis test...");
+  let ast = Parser::parse(
+    &PathBuf::new(),
+    &Namepath::default(),
+    0,
+    &tokens,
+    &PathBuf::new(),
+  )
+  .expect("Parsing failed in analysis test...");
 
   let root = PathBuf::from("justfile");
   let mut asts: HashMap<PathBuf, Ast> = HashMap::new();
