@@ -35,6 +35,7 @@ macro_rules! test {
 }
 
 pub(crate) struct Output {
+  pub(crate) pid: u32,
   pub(crate) stdout: String,
   pub(crate) tempdir: TempDir,
 }
@@ -210,6 +211,8 @@ impl Test {
       .spawn()
       .expect("just invocation failed");
 
+    let pid = child.id();
+
     {
       let mut stdin_handle = child.stdin.take().expect("failed to unwrap stdin handle");
 
@@ -257,8 +260,9 @@ impl Test {
     }
 
     Output {
-      tempdir: self.tempdir,
+      pid,
       stdout: output_stdout.into(),
+      tempdir: self.tempdir,
     }
   }
 }
